summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/spl-cast.h
diff options
context:
space:
mode:
authorDavid Lawrence Ramsey <dolorous@users.sourceforge.net>2009-11-09 23:59:39 -0600
committerDavid Lawrence Ramsey <dolorous@users.sourceforge.net>2009-11-09 23:59:39 -0600
commit5d7a50baaa1a688660fed5da400ff1ebd5c81049 (patch)
tree0779feeed704112196221ba57ef3c9edc28d85e6 /crawl-ref/source/spl-cast.h
parente79ba3e8f21761993dfce92a4d8753dbc8503809 (diff)
downloadcrawl-ref-5d7a50baaa1a688660fed5da400ff1ebd5c81049.tar.gz
crawl-ref-5d7a50baaa1a688660fed5da400ff1ebd5c81049.zip
Add spell flag SPFLAG_HASTY, and mark hasty spells with it.
Diffstat (limited to 'crawl-ref/source/spl-cast.h')
-rw-r--r--crawl-ref/source/spl-cast.h21
1 files changed, 11 insertions, 10 deletions
diff --git a/crawl-ref/source/spl-cast.h b/crawl-ref/source/spl-cast.h
index 60088d64e8..b5b17a4f02 100644
--- a/crawl-ref/source/spl-cast.h
+++ b/crawl-ref/source/spl-cast.h
@@ -23,18 +23,19 @@ enum spflag_type
SPFLAG_NOT_SELF = 0x00040, // aborts on isMe
SPFLAG_UNHOLY = 0x00080, // counts as "unholy"
SPFLAG_CHAOTIC = 0x00100, // counts as "chaotic"
- SPFLAG_MAPPING = 0x00200, // a mapping spell of some kind
- SPFLAG_ESCAPE = 0x00400, // useful for running away
- SPFLAG_RECOVERY = 0x00800, // healing or recovery spell
- SPFLAG_AREA = 0x01000, // area affect
- SPFLAG_BATTLE = 0x02000, // a non-Conjuration spell that
+ SPFLAG_HASTY = 0x00200, // counts as "hasty"
+ SPFLAG_MAPPING = 0x00400, // a mapping spell of some kind
+ SPFLAG_ESCAPE = 0x00800, // useful for running away
+ SPFLAG_RECOVERY = 0x01000, // healing or recovery spell
+ SPFLAG_AREA = 0x02000, // area affect
+ SPFLAG_BATTLE = 0x04000, // a non-Conjuration spell that
// is still a battle spell
- SPFLAG_CARD = 0x04000, // a card effect spell
- SPFLAG_MONSTER = 0x08000, // monster-only spell
- SPFLAG_INNATE = 0x10000, // an innate spell, even if
+ SPFLAG_CARD = 0x08000, // a card effect spell
+ SPFLAG_MONSTER = 0x10000, // monster-only spell
+ SPFLAG_INNATE = 0x20000, // an innate spell, even if
// use by a priest/wizard
- SPFLAG_NOISY = 0x20000, // makes noise, even if innate
- SPFLAG_TESTING = 0x40000 // a testing/debugging spell
+ SPFLAG_NOISY = 0x40000, // makes noise, even if innate
+ SPFLAG_TESTING = 0x80000 // a testing/debugging spell
};
enum spret_type